

#######################################################
empiricals - module with heliospheric empirical modules
#######################################################

.. automodule:: spacepy.empiricals

.. currentmodule:: spacepy.empiricals

.. autosummary::
    :toctree: autosummary

    getLmax
    getPlasmaPause
    getMPstandoff
    getDststar
    getVampolaOrder
    vampolaPA
